@@ -7,7 +7,7 @@ def getDesktop():
         import winreg
         return winreg.QueryValueEx(winreg.OpenKey(winreg.HKEY_CURRENT_USER,r'Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders'),"Desktop")[0]
     except:
-        return os.curdir()
+        return os.curdir
 
 def setu(save = 1):
     # iw233
@@ -24,3 +24,6 @@ def setu(save = 1):
     desk = getDesktop()
     with open(desk + '\\' + randbytes(3).hex() + '.jpg','wb') as f:
         f.write(data)
+
+def setu_pro(save):
+    pass
